--[[
Created: 2020-12-20
Updated: 2022-11-28
Author: Skadi of Dawnbringer-US
AddOn: Broker_GroupHelperRedux
Module: Main
Version: 10.0.2_R18
Description: Broker_GroupHelperRedux is an AddOn that allows you to conveniently access 
             many of the group and raid functions that exist in the game.
--]]

local name, addon = ...
LibStub('AceAddon-3.0'):NewAddon(addon, name, 'AceEvent-3.0', 'LibPubSub-1.0')

-- Localise global variables
local _G = _G
local GetLootSpecialization, SetLootSpecialization = _G.GetLootSpecialization, _G.SetLootSpecialization
local GetSpecializationInfo, GetSpecializationInfoByID = _G.GetSpecializationInfo, _G.GetSpecializationInfoByID
local GetSpecialization = _G.GetSpecialization

function addon:OnInitialize()
	self.L = LibStub('AceLocale-3.0'):GetLocale(name)
	self.db = LibStub("AceDB-3.0"):New("GroupHelperReduxDB", self:GetModule("Database-Defaults"):GetDatabaseDefaults())
	self:GetModule("Config-Main"):RegisterOptions()
	self:RegisterEvent('PLAYER_ENTERING_WORLD', 'TriggerLootSpecUpdated')
	self:RegisterEvent('PLAYER_LOOT_SPEC_UPDATED', 'TriggerLootSpecUpdated')
	self:RegisterEvent('PLAYER_SPECIALIZATION_CHANGED', 'TriggerLootSpecUpdated')
end

function addon:OnEnable()
	self:TriggerLootSpecUpdated()
end

function addon:TriggerLootSpecUpdated()
	self:Publish('LOOT_SPEC_UPDATED')
end

function addon.GetLootSpecialization()
	local id = GetLootSpecialization()

	if id > 0 then
		return id, GetSpecializationInfoByID(id)
	else
		local spec = GetSpecialization()
		if spec then
			return id, GetSpecializationInfo(spec)
		end
	end

	return 0
end

function addon.SetLootSpecialization(spec)
	SetLootSpecialization(spec)
end

function addon:HexColor(color, str)
	if type(color) == "table" then
		return string.format("|cff%02x%02x%02x%s|r", (color.r or 1) * 255, (color.g or 1) * 255, (color.b or 1) * 255, tostring(str))
	end
	return string.format("|cff%s%s|r", tostring(color), tostring(str))
end
