--[[
Created: 2020-12-20
Updated: 2022-11-28
Author: Skadi of Dawnbringer-US
AddOn: Broker_GroupHelperRedux
Module: Configuration-About
Version: 10.0.2_R18
Description: Broker_GroupHelperRedux is an AddOn that allows you to conveniently access 
             many of the group and raid functions that exist in the game.
--]]

local name, addon = ...
local GroupHelperRedux = LibStub("AceAddon-3.0"):GetAddon(name)
local configOptions = addon:NewModule('Config-About')
local L = LibStub("AceLocale-3.0"):GetLocale(name)

local function Broker_GroupHelperRedux_GetNotes()
	return GetAddOnMetadata(name, "Notes") or L.EmptyString;
end

local function Broker_GroupHelperRedux_GetVersion()
	return GetAddOnMetadata(name, "Version") or L.EmptyString;
end

local function Broker_GroupHelperRedux_GetAuthor()
	return GetAddOnMetadata(name, "Author") or L.EmptyString;
end

local function Broker_GroupHelperRedux_GetCategory()
	return GetAddOnMetadata(name, "X-Category") or L.EmptyString;
end

local function Broker_GroupHelperRedux_GetLicense()
	return GetAddOnMetadata(name, "X-License") or L.EmptyString;
end

local function Broker_GroupHelperRedux_GetWebsite()
	return GetAddOnMetadata(name, "X-Website") or L.EmptyString;
end

local aboutOptions = {
	name = BROKER_GROUPHELPERREDUX_CONFIG.Topic.About,
	type = "group",
	args = {
		confgendesc = {
			order = 1,
			type = "description",
			name = Broker_GroupHelperRedux_GetNotes().."\n\n",
			cmdHidden = true
		},
		confinfodesc = {
			name = "About",
			type = "group", 
            inline = true,
			args = {
				confversiondesc = {
				    order = 1,
				    type = "description",
				    name = GroupHelperRedux:HexColor(L.HexFontTextColorTangerineYellow, L.AboutVersionLabel .. L.ColonSpaceString) .. GroupHelperRedux:HexColor(L.HexFontTextColorSpringGreen, Broker_GroupHelperRedux_GetVersion()),
				    cmdHidden = true
				},
				confauthordesc = {
					order = 2,
					type = "description",
				    name = GroupHelperRedux:HexColor(L.HexFontTextColorTangerineYellow, L.AboutAuthorLabel .. L.ColonSpaceString) .. GroupHelperRedux:HexColor(L.HexFontTextColorDarkSaturatedOrange, Broker_GroupHelperRedux_GetAuthor()),
					cmdHidden = true
				},				
				confcatdesc = {
					order = 3,
					type = "description",
					name = GroupHelperRedux:HexColor(L.HexFontTextColorTangerineYellow, L.AboutCategoryLabel .. L.ColonSpaceString) .. GroupHelperRedux:HexColor(L.HexFontTextColorWhite, Broker_GroupHelperRedux_GetCategory()),
					cmdHidden = true
				},
				confwebsitedesc = {
					order = 4,
					type = "description",
					name = GroupHelperRedux:HexColor(L.HexFontTextColorTangerineYellow, L.AboutWebsiteLabel .. L.ColonSpaceString) .. GroupHelperRedux:HexColor(L.HexFontTextColorWhite, Broker_GroupHelperRedux_GetWebsite()),
					cmdHidden = true
				},
				conflicensedesc = {
					order = 5,
					type = "description",
					name = GroupHelperRedux:HexColor(L.HexFontTextColorTangerineYellow, L.AboutLicenseLabel .. L.ColonSpaceString) .. GroupHelperRedux:HexColor(L.HexFontTextColorWhite, Broker_GroupHelperRedux_GetLicense()),
					cmdHidden = true
				},
			}
		}
	}
}

function configOptions:GetAboutOptions()	
	return aboutOptions
end
