--[[
Created: 2020-12-20
Updated: 2022-11-28
Author: Skadi of Dawnbringer-US
AddOn: Broker_GroupHelperRedux
Module: Configuration-Dropdown Text Colors
Version: 10.0.2_R18
Description: Broker_GroupHelperRedux is an AddOn that allows you to conveniently access 
             many of the group and raid functions that exist in the game.
--]]

local name, addon = ...
local GroupHelperRedux = LibStub("AceAddon-3.0"):GetAddon(name)
local configOptions = addon:NewModule('Config-DropdownTextColors')
local L = LibStub("AceLocale-3.0"):GetLocale(name)

local function get(info)
	local p, c = string.split(".", info.arg)
	
	if p == "customDropdownColors" then
		return GroupHelperRedux.db.profile.DropdownTextColorOptions[c].r, GroupHelperRedux.db.profile.DropdownTextColorOptions[c].g, GroupHelperRedux.db.profile.DropdownTextColorOptions[c].b
	end
end

local function set(info, arg1, arg2, arg3, arg4)
	local p, c = string.split(".", info.arg)
	
	if p == "customDropdownColors" then
		GroupHelperRedux.db.profile.DropdownTextColorOptions[c].r = arg1
		GroupHelperRedux.db.profile.DropdownTextColorOptions[c].g = arg2
		GroupHelperRedux.db.profile.DropdownTextColorOptions[c].b = arg3
	end
end

local dorpdownTextColorOptions = { 
    name = BROKER_GROUPHELPERREDUX_CONFIG.Topic.DropdownColors,
    handler = Broker_GroupHelperRedux_H3,
	type='group',
	childGroups = "tab",
    args = {
		DropdownTextColorOptions = {
			inline = true,
			name = BROKER_GROUPHELPERREDUX_CONFIG.Topic.DropdownColorsDesc,
			type = "group", 
			order = 1,			
			args = {
				dropdownTitleHeaderColor = {
					order = 1,
					type = "color",
					name = L.DropdownTitleHeaderColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.DropdownTitleHeaderColorExampleText .. L.RightParenthesis),
					desc= L.DropdownTitleHeaderColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.dropdownTitleHeaderColor",
				},
				readyCheckColor = {
					order = 2,
					type = "color",
					name = L.ReadyCheckColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.ReadyCheckColorExampleText .. L.RightParenthesis),
					desc= L.ReadyCheckColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.readyCheckColor",
				},
				dungeonsAndRaidsHeaderColor = {
					order = 3,
					type = "color",
					name = L.DungeonsAndRaidsHeaderColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.DungeonsAndRaidsHeaderColorExampleText .. L.RightParenthesis),
					desc= L.DungeonsAndRaidsHeaderColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.dungeonsAndRaidsHeaderColor",
				},
				legendaryPowersColor = {
					order = 4,
					type = "color",
					name = L.LegendaryPowersColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.LegendaryPowersColorExampleText .. L.RightParenthesis),
					desc= L.LegendaryPowersColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.legendaryPowersColor",
				},
				mythicKeystonesColor = {
					order = 5,
					type = "color",
					name = L.MythicKeystonesColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.MythicKeystonesColorExampleText .. L.RightParenthesis),
					desc= L.MythicKeystonesColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.mythicKeystonesColor",
				},
				calendarColor = {
					order = 6,
					type = "color",
					name = L.CalendarColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.CalendarColorExampleText .. L.RightParenthesis),
					desc= L.CalendarColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.calendarColor",
				},
				adventureGuideColor = {
					order = 7,
					type = "color",
					name = L.AdventureGuideColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.AdventureGuideColorExampleText .. L.RightParenthesis),
					desc= L.AdventureGuideColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.adventureGuideColor",
				},
				greatVaultColor = {
					order = 8,
					type = "color",
					name = L.GreatVaultColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.GreatVaultColorExampleText .. L.RightParenthesis),
					desc= L.GreatVaultColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.greatVaultColor",
				},
				dungeonFinderColor = {
					order = 9,
					type = "color",
					name = L.DungeonFinderColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.DungeonFinderColorExampleText .. L.RightParenthesis),
					desc= L.DungeonFinderColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.dungeonFinderColor",
				},
				raidFinderColor = {
					order = 10,
					type = "color",
					name = L.RaidFinderColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.RaidFinderColorExampleText .. L.RightParenthesis),
					desc= L.RaidFinderColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.raidFinderColor",
				},						
				premadeGroupsColor = {
					order = 11,
					type = "color",
					name = L.PremadeGroupsColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.PremadeGroupsColorExampleText .. L.RightParenthesis),
					desc= L.PremadeGroupsColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.premadeGroupsColor",
				},
				groupUtilityOptionsHeaderColor = {
					order = 12,
					type = "color",
					name = L.GroupUtilityOptionsHeaderColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.GroupUtilityOptionsHeaderColorExampleText .. L.RightParenthesis),
					desc= L.GroupUtilityOptionsHeaderColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.groupUtilityOptionsHeaderColor",
				},
				teleportInOutOfLFGInstanceColor = {
					order = 13,
					type = "color",
					name = L.TeleportInOutOfLFGInstanceColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.TeleportInOutOfLFGInstanceColorExampleText .. L.RightParenthesis),
					desc= L.TeleportInOutOfLFGInstanceColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.teleportInOutOfLFGInstanceColor",
				},
				raidColor = {
					order = 14,
					type = "color",
					name = L.RaidColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.RaidColorExampleText .. L.RightParenthesis),
					desc= L.RaidColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.raidColor",
				},
				raidInfoColor = {
					order = 15,
					type = "color",
					name = L.RaidInfoColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.RaidInfoColorExampleText .. L.RightParenthesis),
					desc= L.RaidInfoColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.raidInfoColor",
				},
				convertToRaidColor = {
					order = 16,
					type = "color",
					name = L.ConvertToRaidColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.ConvertToRaidColorExampleText .. L.RightParenthesis),
					desc= L.ConvertToRaidColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.convertToRaidColor",
				},
				disbandRaidColor = {
					order = 17,
					type = "color",
					name = L.DisbandRaidColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.DisbandRaidColorExampleText .. L.RightParenthesis),
					desc= L.DisbandRaidColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.disbandRaidColor",
				},
				resetAllInstancesColor = {
					order = 18,
					type = "color",
					name = L.ResetAllInstancesColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.ResetAllInstancesColorExampleText .. L.RightParenthesis),
					desc= L.ResetAllInstancesColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.resetAllInstancesColor",
				},
				leaveGroupQueueOptionsHeaderColor = {
					order = 19,
					type = "color",
					name = L.LeaveGroupQueueOptionsHeaderColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.LeaveGroupQueueOptionsHeaderColorExampleText .. L.RightParenthesis),
					desc= L.LeaveGroupQueueOptionsHeaderColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.leaveGroupQueueOptionsHeaderColor",
				},
				leaveGroupColor = {
					order = 20,
					type = "color",
					name = L.LeaveGroupColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.LeaveGroupColorExampleText .. L.RightParenthesis),
					desc= L.LeaveGroupColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.leaveGroupColor",
				},					
				leaveTheDungeonFinderQueueColor = {
					order = 21,
					type = "color",
					name = L.LeaveTheDungeonFinderQueueColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.LeaveTheDungeonFinderQueueColorExampleText .. L.RightParenthesis),
					desc= L.LeaveTheDungeonFinderQueueColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.leaveTheDungeonFinderQueueColor",
				},
				leaveTheRaidFinderQueueColor = {
					order = 22,
					type = "color",
					name = L.LeaveTheRaidFinderQueueColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.LeaveTheRaidFinderQueueColorExampleText .. L.RightParenthesis),
					desc= L.LeaveTheRaidFinderQueueColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.leaveTheRaidFinderQueueColor",
				},
				dungeonDifficultyHeaderColor = {
					order = 23,
					type = "color",
					name = L.DungeonDifficultyHeaderColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.DungeonDifficultyHeaderColorExampleText .. L.RightParenthesis),
					desc= L.DungeonDifficultyHeaderColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.dungeonDifficultyHeaderColor",
				},
				dungeonDifficultyOptionsColor = {
					order = 24,
					type = "color",
					name = L.DungeonDifficultyOptionsColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.DungeonDifficultyOptionsColorExampleText .. L.RightParenthesis),
					desc= L.DungeonDifficultyOptionsColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.dungeonDifficultyOptionsColor",
				},
				selectADungeonDifficultyHeaderColor = {
					order = 25,
					type = "color",
					name = L.SelectADungeonDifficultyHeaderColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.SelectADungeonDifficultyHeaderColorExampleText .. L.RightParenthesis),
					desc= L.SelectADungeonDifficultyHeaderColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.selectADungeonDifficultyHeaderColor",
				},
				dungeonDifficultyNormalColor = {
					order = 26,
					type = "color",
					name = L.DungeonDifficultyNormalColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.DungeonDifficultyNormalColorExampleText .. L.RightParenthesis),
					desc= L.DungeonDifficultyNormalColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.dungeonDifficultyNormalColor",
				},
				dungeonDifficultyHeroicColor = {
					order = 27,
					type = "color",
					name = L.DungeonDifficultyHeroicColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.DungeonDifficultyHeroicColorExampleText .. L.RightParenthesis),
					desc= L.DungeonDifficultyHeroicColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.dungeonDifficultyHeroicColor",
				},
				dungeonDifficultyMythicColor = {
					order = 28,
					type = "color",
					name = L.DungeonDifficultyMythicColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.DungeonDifficultyMythicColorExampleText .. L.RightParenthesis),
					desc= L.DungeonDifficultyMythicColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.dungeonDifficultyMythicColor",
				},
				raidDifficultyHeaderColor = {
					order = 29,
					type = "color",
					name = L.RaidDifficultyHeaderColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.RaidDifficultyHeaderColorExampleText .. L.RightParenthesis),
					desc= L.RaidDifficultyHeaderColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.raidDifficultyHeaderColor",
				},
				raidDifficultyOptionsColor = {
					order = 30,
					type = "color",
					name = L.RaidDifficultyOptionsColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.RaidDifficultyOptionsColorExampleText .. L.RightParenthesis),
					desc= L.RaidDifficultyOptionsColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.raidDifficultyOptionsColor",
				},					
				selectARaidDifficultyHeaderColor = {
					order = 31,
					type = "color",
					name = L.SelectARaidDifficultyHeaderColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.SelectARaidDifficultyHeaderColorExampleText .. L.RightParenthesis),
					desc= L.SelectARaidDifficultyHeaderColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.selectARaidDifficultyHeaderColor",
				},
				raidDifficultyNormalColor = {
					order = 32,
					type = "color",
					name = L.RaidDifficultyNormalColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.RaidDifficultyNormalColorExampleText .. L.RightParenthesis),
					desc= L.RaidDifficultyNormalColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.raidDifficultyNormalColor",
				},
				raidDifficulty10PlayerColor = {
					order = 33,
					type = "color",
					name = L.RaidDifficulty10PlayerColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.RaidDifficulty10PlayerColorExampleText .. L.RightParenthesis),
					desc= L.RaidDifficulty10PlayerColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.raidDifficulty10PlayerColor",
				},
				raidDifficulty25PlayerColor = {
					order = 34,
					type = "color",
					name = L.RaidDifficulty25PlayerColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.RaidDifficulty25PlayerColorExampleText .. L.RightParenthesis),
					desc= L.RaidDifficulty25PlayerColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.raidDifficulty25PlayerColor",
				},
				raidDifficultyHeroicColor = {
					order = 35,
					type = "color",
					name = L.RaidDifficultyHeroicColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.RaidDifficultyHeroicColorExampleText .. L.RightParenthesis),
					desc= L.RaidDifficultyHeroicColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.raidDifficultyHeroicColor",
				},
				raidDifficulty10PlayerHeroicColor = {
					order = 36,
					type = "color",
					name = L.RaidDifficulty10PlayerHeroicColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.RaidDifficulty10PlayerHeroicColorExampleText .. L.RightParenthesis),
					desc= L.RaidDifficulty10PlayerHeroicColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.raidDifficulty10PlayerHeroicColor",
				},
				raidDifficulty25PlayerHeroicColor = {
					order = 37,
					type = "color",
					name = L.RaidDifficulty25PlayerHeroicColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.RaidDifficulty25PlayerHeroicColorExampleText .. L.RightParenthesis),
					desc= L.RaidDifficulty25PlayerHeroicColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.raidDifficulty25PlayerHeroicColor",
				},
				raidDifficultyMythicColor = {
					order = 38,
					type = "color",
					name = L.MythicRaidDifficultyColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.MythicRaidDifficultyColorExampleText .. L.RightParenthesis),
					desc= L.MythicRaidDifficultyColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.raidDifficultyMythicColor",
				},
				legacyRaidDifficultyHeaderColor = {
					order = 39,
					type = "color",
					name = L.LegacyRaidDifficultyHeaderColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.LegacyRaidDifficultyHeaderColorExampleText .. L.RightParenthesis),
					desc= L.LegacyRaidDifficultyHeaderColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.legacyRaidDifficultyHeaderColor",
				},
				legacyRaidDifficultyOptionsColor = {
					order = 40,
					type = "color",
					name = L.LegacyRaidDifficultyOptionsColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.LegacyRaidDifficultyOptionsColorExampleText .. L.RightParenthesis),
					desc= L.LegacyRaidDifficultyOptionsColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.legacyRaidDifficultyOptionsColor",
				},
				selectALegacyRaidDifficultyHeaderColor = {
					order = 41,
					type = "color",
					name = L.SelectALegacyRaidDifficultyHeaderColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.SelectALegacyRaidDifficultyHeaderColorExampleText .. L.RightParenthesis),
					desc= L.SelectALegacyRaidDifficultyHeaderColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.selectALegacyRaidDifficultyHeaderColor",
				},
				legacyRaidDifficulty10PlayerColor = {
					order = 42,
					type = "color",
					name = L.LegacyRaidDifficulty10PlayerColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.LegacyRaidDifficulty10PlayerColorExampleText .. L.RightParenthesis),
					desc= L.LegacyRaidDifficulty10PlayerColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.legacyRaidDifficulty10PlayerColor",
				},					
				legacyRaidDifficulty25PlayerColor = {
					order = 43,
					type = "color",
					name = L.LegacyRaidDifficulty25PlayerColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.LegacyRaidDifficulty25PlayerColorExampleText .. L.RightParenthesis),
					desc= L.LegacyRaidDifficulty25PlayerColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.legacyRaidDifficulty25PlayerColor",
				},
				legacyRaidDifficulty10PlayerHeroicColor = {
					order = 45,
					type = "color",
					name = L.LegacyRaidDifficulty10PlayerHeroicColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.LegacyRaidDifficulty10PlayerHeroicColorExampleText .. L.RightParenthesis),
					desc= L.LegacyRaidDifficulty10PlayerHeroicColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.legacyRaidDifficulty10PlayerHeroicColor",
				},
				legacyRaidDifficulty25PlayerHeroicColor = {
					order = 46,
					type = "color",
					name = L.LegacyRaidDifficulty25PlayerHeroicColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.LegacyRaidDifficulty25PlayerHeroicColorExampleText .. L.RightParenthesis),
					desc= L.LegacyRaidDifficulty25PlayerHeroicColorDesc,
					width = "full",
					hasAlpha = false,					
					get = get,
					set = set,
					arg = "customDropdownColors.legacyRaidDifficulty25PlayerHeroicColor",
				},
			}
		},
	}
}

function configOptions:GetDropdownTextColorOptions()	
	return dorpdownTextColorOptions
end
