--[[
Created: 2020-12-20
Updated: 2022-11-28
Author: Skadi of Dawnbringer-US
AddOn: Broker_GroupHelperRedux
Module: Configuration-Tooltip Text Colors
Version: 10.0.2_R18
Description: Broker_GroupHelperRedux is an AddOn that allows you to conveniently access 
             many of the group and raid functions that exist in the game.
--]]

local name, addon = ...
local GroupHelperRedux = LibStub("AceAddon-3.0"):GetAddon(name)
local configOptions = addon:NewModule('Config-TooltipTextColors')
local L = LibStub("AceLocale-3.0"):GetLocale(name)

local function get(info)
	local p, c = string.split(".", info.arg)
	
	if p == "customTooltipColors" then
		return GroupHelperRedux.db.profile.TooltipTextColorOptions[c].r, GroupHelperRedux.db.profile.TooltipTextColorOptions[c].g, GroupHelperRedux.db.profile.TooltipTextColorOptions[c].b
	end
end

local function set(info, arg1, arg2, arg3, arg4)
	local p, c = string.split(".", info.arg)
	
	if p == "customTooltipColors" then
		GroupHelperRedux.db.profile.TooltipTextColorOptions[c].r = arg1
		GroupHelperRedux.db.profile.TooltipTextColorOptions[c].g = arg2
		GroupHelperRedux.db.profile.TooltipTextColorOptions[c].b = arg3
	end
end

local tooltipTextColorOptions = { 
    name = BROKER_GROUPHELPERREDUX_CONFIG.Topic.TooltipColors,
    handler = Broker_GroupHelperRedux_H2,
	type='group',
	childGroups = "tab",
    args = {
		TooltipTextColorOptions = {
			inline = true,
			name = BROKER_GROUPHELPERREDUX_CONFIG.Topic.TooltipColorsDesc,
			type = "group", 
			order = 1,			
			args = {
				tooltipTitleHeaderColor = {
					order = 1,
					type = "color",
					name = L.TooltipTitleHeaderColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.TooltipTitleHeaderExampleText .. L.RightParenthesis),
					desc= L.TooltipTitleHeaderColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.tooltipTitleHeaderColor",
				},
				configurationOptionsColor = {
					order = 2,
					type = "color",
					name = L.ConfigurationOptionsColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.ConfigurationOptionsColorExampleText .. L.RightParenthesis),
					desc= L.ConfigurationOptionsColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.configurationOptionsColor",
				},
				lootInfoHeaderColor = {
					order = 3,
					type = "color",
					name = L.LootInfoHeaderColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.LootInfoHeaderColorExampleText .. L.RightParenthesis),
					desc= L.LootInfoHeaderColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.lootInfoHeaderColor",
				},
				lootSpecLabelColor = {
					order = 4,
					type = "color",
					name = L.LootSpecLabelColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.LootSpecLabelColorExampleText .. L.RightParenthesis),
					desc= L.LootSpecLabelColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.lootSpecLabelColor",
				},
				lootSpecValueColor = {
					order = 5,
					type = "color",
					name = L.LootSpecValueColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.LootSpecValueColorExampleText .. L.RightParenthesis),
					desc= L.LootSpecValueColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.lootSpecValueColor",
				},
				lootSpecSelectionHeaderColor = {
					order = 6,
					type = "color",
					name = L.LootSpecSelectionHeaderColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.LootSpecSelectionHeaderColorExampleText .. L.RightParenthesis),
					desc= L.LootSpecSelectionHeaderColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.lootSpecSelectionHeaderColor",
				},
				lootSpecPrimaryValueColor = {
					order = 7,
					type = "color",
					name = L.LootSpecPrimaryValueColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.LootSpecPrimaryValueColorExampleText .. L.RightParenthesis),
					desc= L.LootSpecPrimaryValueColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.lootSpecPrimaryValueColor",
				},
				lootSpecSecondaryValueColor = {
					order = 8,
					type = "color",
					name = L.LootSpecSecondaryValueColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.LootSpecSecondaryValueColorExampleText .. L.RightParenthesis),
					desc= L.LootSpecSecondaryValueColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.lootSpecSecondaryValueColor",
				},				
				instanceInfoHeaderColor = {
					order = 9,
					type = "color",
					name = L.InstanceInfoHeaderColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.InstanceInfoHeaderColorExampleText .. L.RightParenthesis),
					desc= L.InstanceInfoHeaderColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.instanceInfoHeaderColor",
				},
				instanceInfoNameLabelColor = {
					order = 10,
					type = "color",
					name = L.InstanceInfoNameLabelColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.InstanceInfoNameLabelColorExampleText .. L.RightParenthesis),
					desc= L.InstanceInfoNameLabelColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.instanceInfoNameLabelColor",
				},
				instanceInfoNameValueColor = {
					order = 11,
					type = "color",
					name = L.InstanceInfoNameValueColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.InstanceInfoNameValueColorExampleText .. L.RightParenthesis),
					desc= L.InstanceInfoNameValueColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.instanceInfoNameValueColor",
				},
				instanceSubzoneLabelColor = {
					order = 12,
					type = "color",
					name = L.InstanceSubzoneLabelColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.InstanceSubzoneLabelColorExampleText .. L.RightParenthesis),
					desc= L.InstanceSubzoneLabelColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.instanceSubzoneLabelColor",
				},
				instanceSubzoneValueColor = {
					order = 13,
					type = "color",
					name = L.InstanceSubzoneValueColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.InstanceSubzoneValueColorExampleText .. L.RightParenthesis),
					desc= L.InstanceSubzoneValueColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.instanceSubzoneValueColor",
				},
				instanceInfoDungeonDiffLabelColor = {
					order = 14,
					type = "color",
					name = L.InstanceInfoDungeonDiffLabelColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.InstanceInfoDungeonDiffLabelColorExampleText .. L.RightParenthesis),
					desc= L.InstanceInfoDungeonDiffLabelColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.instanceInfoDungeonDiffLabelColor",
				},
				instanceInfoDungeonDiffValueColor = {
					order = 15,
					type = "color",
					name = L.InstanceInfoDungeonDiffValueColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.InstanceInfoDungeonDiffValueColorExampleText .. L.RightParenthesis),
					desc= L.InstanceInfoDungeonDiffValueColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.instanceInfoDungeonDiffValueColor",
				},
				instanceInfoRaidDiffLabelColor = {
					order = 16,
					type = "color",
					name = L.InstanceInfoRaidDiffLabelColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.InstanceInfoRaidDiffLabelColorExampleText .. L.RightParenthesis),
					desc= L.InstanceInfoRaidDiffLabelColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.instanceInfoRaidDiffLabelColor",
				},
				instanceInfoRaidDiffValueColor = {
					order = 17,
					type = "color",
					name = L.InstanceInfoRaidDiffValueColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.InstanceInfoRaidDiffValueColorExampleText .. L.RightParenthesis),
					desc= L.InstanceInfoRaidDiffValueColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.instanceInfoRaidDiffValueColor",
				},
				instanceInfoLegacyRaidDifficultyLabelColor = {
					order = 18,
					type = "color",
					name = L.InstanceInfoLegacyRaidDifficultyLabelColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.InstanceInfoLegacyRaidDifficultyLabelColorExampleText .. L.RightParenthesis),
					desc= L.InstanceInfoLegacyRaidDifficultyLabelColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.instanceInfoLegacyRaidDifficultyLabelColor",
				},
				instanceInfoLegacyRaidDifficultyValueColor = {
					order = 19,
					type = "color",
					name = L.InstanceInfoLegacyRaidDifficultyValueColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.InstanceInfoLegacyRaidDifficultyValueColorExampleText .. L.RightParenthesis),
					desc= L.InstanceInfoLegacyRaidDifficultyValueColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.instanceInfoLegacyRaidDifficultyValueColor",
				},
				instanceQueuesHeaderColor = {
					order = 20,
					type = "color",
					name = L.InstanceQueuesHeaderColorLabel .. L.HyphenSpaceString .. GroupHelperRedux:HexColor(L.HexFontTextColorDodgerBlue, L.LeftParenthesis .. L.InstanceQueuesHeaderColorExampleText .. L.RightParenthesis),
					desc= L.InstanceQueuesHeaderColorDesc,
					width = "full",
					hasAlpha = false,
					get = get,
					set = set,
					arg = "customTooltipColors.instanceQueuesHeaderColor",
				}
			}
		},
	}
}

function configOptions:GetTooltipTextColorOptions()	
	return tooltipTextColorOptions
end
