--[[
Created: 2020-12-20
Updated: 2022-11-28
Author: Skadi of Dawnbringer-US
AddOn: Broker_GroupHelperRedux
Module: Dropdown
Version: 10.0.2_R18
Description: Broker_GroupHelperRedux is an AddOn that allows you to conveniently access 
             many of the group and raid functions that exist in the game.
--]]

local name, addon = ...
local Dropdown = addon:NewModule("Dropdown")
local L = LibStub("AceLocale-3.0"):GetLocale(name)
local LibDropdown = LibStub("LibDropdown-1.0")

function Dropdown:PopulateDropdown(myframe)
	-- release if if already shown
	local barmenuframe
	barmenuframe = barmenuframe and barmenuframe:Release()
	local baropts = {
		type = 'group',
		args = {
			title_header = {
				order = 10,    	
				type = 'header',
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.dropdownTitleHeaderColor, L.Broker_GroupHelperReduxHeader .. L.ColonSpaceString .. L.ReleaseVersion),
			},
			ready_check_function = {
				order = 20,
				type = 'execute', 
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.readyCheckColor, L.ReadyCheckLabel),
				desc = L.ReadyCheckDesc,
				func = function()						
						DoReadyCheck()
					   end, 			
			},
			dungeon_and_raids_separator_header = { 
				order = 30,   
				type = 'header',
				name = L.EmptyString,
			},				
			dungeon_and_raids_header = {
				order = 40,    	
				type = 'header',
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.dungeonsAndRaidsHeaderColor, L.DungeonsandRaidsHeader),
			},					
			mythic_keystones_function = {
				order = 44,
				type = 'execute', 
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.mythicKeystonesColor, L.MythicKeystonesLabel),				
				desc = L.MythicKeystonesDesc,
				func = function()
						securecall("PVEFrame_ToggleFrame","ChallengesFrame")
					   end, 			
			},
			calendar_function = {
				order = 45,
				type = 'execute', 
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.calendarColor, L.CalendarLabel),				
				desc = L.CalendarDesc,
				func = function()
						ToggleCalendar()
					   end,
			},			
			instance_encounter_journal_function = {
				order = 50,
				type = 'execute', 
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.adventureGuideColor, L.AdventureGuideLabel),				
				desc = L.AdventureGuideDesc,
				func = function()						
						addon:GetModule("Click"):OnAdventureGuideClick()
					   end,
			},
			instance_great_vault_function = {
				order = 55,
				type = 'execute', 
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.greatVaultColor, L.GreatVaultLabel),				
				desc = L.GreatVaultDesc,
				func = function()
					    addon:ToggleGreatVault()
					   end,
			},
			instance_dungeon_finder_function = {
				order = 60,
				type = 'execute', 
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.dungeonFinderColor, L.DungeonFinderLabel),				
				desc = L.DungeonFinderDesc,
				func = function() 
						ToggleLFDParentFrame()
					   end, 			
			},
 			instance_raid_finder_function = {
				order = 70,
				type = 'execute', 
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.raidFinderColor, L.RaidFinderLabel),  				
				desc = L.RaidFinderDesc,
				func = function()
						addon:OpenLFRFrame()
					   end, 			
			},
			instance_premade_groups_function = {
				order = 75,
				type = 'execute', 
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.premadeGroupsColor, L.PremadeGroupsLabel),  				
				desc = L.PremadeGroupsDesc,
				func = function()
						addon:OpenPremadeGroupsFrame()
					   end, 			
			},
			group_utility_options_separator_header = { 
				order = 100,   
				type = 'header',
				name = L.EmptyString,
			},	
			group_utility_options_header = {
				order = 110,    	
				type = 'header',
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.groupUtilityOptionsHeaderColor, L.GroupUtilityOptionsHeader),				
			},
			group_utility_teleport_lfg_function = {
				order = 114,
				type = 'execute', 
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.teleportInOutOfLFGInstanceColor, L.TeleportInOutOfLFGInstanceLabel),				
				desc = L.TeleportInOutOfLFGInstanceDesc,
				func = function() 
						LFGTeleport(IsInLFGDungeon())
					   end, 			
			},
			group_utility_raid_function = {
				order = 115,
				type = 'execute', 
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.raidColor, L.RaidLabel),				
				desc = L.RaidDesc,
				func = function() 
						ToggleRaidFrame()
					   end, 			
			},
			group_utility_raid_info_function = {
				order = 116,
				type = 'execute', 
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.raidInfoColor, L.RaidInfoLabel),				
				desc = L.RaidInfoDesc,
				func = function()
						if (( GetNumSavedInstances() > 0) and not RaidInfoFrame:IsShown()) then
							ToggleFriendsFrame(3)
							RaidInfoFrame:Show()
						elseif (not RaidFrame:IsShown()) then
							ToggleFriendsFrame(3)
						end
					   end, 			
			},
			group_utility_convert_to_raid = {
				order = 120,
				type = 'execute', 
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.convertToRaidColor, L.ConvertToRaidLabel),				
				desc = L.ConvertToRaidDesc,
				func = function() 
						C_PartyInfo.ConvertToRaid()
					   end, 			
			},		
			group_utility_disband_raid = {
				order = 130,
				type = 'execute', 
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.disbandRaidColor, L.DisbandRaidLabel),				
				desc = L.DisbandRaidDesc,
				func = function() 
						return StaticPopup_Show("CONFIRM_DISBAND_RAID") 
					   end, 	    			    			  			
			},
			group_utility_reset_function = {
				order = 135,
				type = 'execute', 
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.resetAllInstancesColor, L.ResetInstancesLabel),				
				desc = L.ResetInstancesDesc,
				func = function() 
						return StaticPopup_Show("CONFIRM_INSTANCE_RESET") 
					   end, 	    			    			  			
			},
			lgq_separator_header = { 
				order = 140,   
				type = 'header',
				name = L.EmptyString,
			},			
			lgq_header = { 
				order = 141,   
				type = 'header',
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.leaveGroupQueueOptionsHeaderColor, L.LeaveGroupQueueOptionsHeaderLabel),				
			},		
			lgq_leave_group = {
				order = 142,    	
				type = 'execute', 
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.leaveGroupColor, L.LeaveGroupLabel),				
				desc = L.LeaveGroupDesc,
				func = function()
						return StaticPopup_Show("CONFIRM_LEAVE_GROUP")
					   end, 			
			},				
			lgq_leave_dungeon_finder_queue_function = {
				order = 143,
				type = 'execute', 
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.leaveTheDungeonFinderQueueColor, L.LeaveDungeonFinderQueueLabel),  				
				desc = L.LeaveDungeonFinderQueueDesc,
				func = function() 
						return StaticPopup_Show("CONFIRM_LEAVE_DUNGEON_FINDER_QUEUE") 
					   end, 			
			},
			lgq_leave_raid_finder_queue_function = {
				order = 144,
				type = 'execute', 
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.leaveTheRaidFinderQueueColor, L.LeaveRaidFinderQueueLabel),  				
				desc = L.LeaveRaidFinderQueueDesc,
				func = function() 
						return StaticPopup_Show("CONFIRM_LEAVE_RAID_FINDER_QUEUE") 
				   	   end,
			},
			dungeon_difficulty_group_separator_header = { 
				order = 150,   
				type = 'header',
				name = L.EmptyString,
			},
			dungeon_difficulty_group_header = { 
				order = 160,   
				type = 'header',
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.dungeonDifficultyHeaderColor, L.DungeonDifficultyHeaderLabel),											    
			},			
			dungeon_difficulty_group_options = {
				order = 170,
				type = 'group',
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.dungeonDifficultyOptionsColor, L.DungeonDifficultyGroupOptionsLabel),				
				desc = L.DungeonDifficultyGroupOptionsDesc,
				args = {	
					dungeon_difficulty_group_options_separator_header = { 
						order = 171,   
						type = 'header',
						name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.selectADungeonDifficultyHeaderColor, L.DungeonDifficultySelectHeader),						
					},					
					dungeon_difficulty_normal = {
						order = 172,
						type = "execute", 
						name = addon:GetDifficultyPrefix(1,"dungeon")..addon:HexColor(addon.db.profile.DropdownTextColorOptions.dungeonDifficultyNormalColor, L.DungeonDifficultyNormalLabel)..addon:GetDifficultyPostfix(1,"dungeon"),						
						desc = L.DungeonDifficultyNormalDesc, 
						func = function() 
								SetDungeonDifficultyID(1)
						       end,						
					},				    
					dungeon_difficulty_heroic = {
						order = 173,						
						type = "execute", 
						name = addon:GetDifficultyPrefix(2,"dungeon")..addon:HexColor(addon.db.profile.DropdownTextColorOptions.dungeonDifficultyHeroicColor, L.DungeonDifficultyHeroicLabel)..addon:GetDifficultyPostfix(2,"dungeon"),						
						desc = L.DungeonDifficultyHeroicDesc, 
						func = function() 
								SetDungeonDifficultyID(2)
						   	   end,						
					},	
					dungeon_difficulty_mythic = {
						order = 174,						
						type = "execute", 
						name = addon:GetDifficultyPrefix(23,"dungeon")..addon:HexColor(addon.db.profile.DropdownTextColorOptions.dungeonDifficultyMythicColor, L.DungeonDifficultyMythicLabel)..addon:GetDifficultyPostfix(23,"dungeon"),						
						desc = L.DungeonDifficultyMythicDesc, 
						func = function() 
								SetDungeonDifficultyID(23)
						       end,						
					},				    				    								
				},
			},
			raid_difficulty_group_separator_header = { 
				order = 180,   
				type = 'header',
				name = L.EmptyString,
			},			
			raid_difficulty_group_header = { 
				order = 190,   
				type = 'header',
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.raidDifficultyHeaderColor, L.RaidDifficultyHeaderLabel),
				
			},			
			raid_difficulty_group_options = {
				order = 200,
				type = 'group',
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.raidDifficultyOptionsColor, L.RaidDifficultyGroupOptionsLabel),				
				desc = L.RaidDifficultyGroupOptionsDesc,
				args = {	
					raid_difficulty_group_options_separator_header = { 
						order = 201,   
						type = 'header',
						name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.selectARaidDifficultyHeaderColor, L.RaidDifficultySelectHeader),						
					},
					raid_difficulty_normal = {
						order = 202,						
						type = "execute", 						
						name = addon:GetDifficultyPrefix(14,"raid")..addon:HexColor(addon.db.profile.DropdownTextColorOptions.raidDifficultyNormalColor, L.RaidDifficultyNormalLabel)..addon:GetDifficultyPostfix(14,"raid"),						
						desc = L.RaidDifficultyNormalDesc, 
						func = function() 
								SetRaidDifficultyID(14)
						       end,						
					},
					raid_difficulty_10_player = {
						order = 203,
						type = "execute", 
						name = addon:GetDifficultyPrefix(3,"raid")..addon:HexColor(addon.db.profile.DropdownTextColorOptions.raidDifficulty10PlayerColor, L.RaidDifficulty10PlayerLabel)..addon:GetDifficultyPostfix(3,"raid"),						
						desc = L.RaidDifficulty10PlayerDesc, 
						func = function() 
								SetRaidDifficultyID(3)
						       end,						
					},	
					raid_difficulty_25_player = {
						order = 204,
						type = "execute", 
						name = addon:GetDifficultyPrefix(4,"raid")..addon:HexColor(addon.db.profile.DropdownTextColorOptions.raidDifficulty25PlayerColor, L.RaidDifficulty25PlayerLabel)..addon:GetDifficultyPostfix(4,"raid"),						
						desc = L.RaidDifficulty25PlayerDesc, 
						func = function() 
								SetRaidDifficultyID(4)
						       end,						
					},
					raid_difficulty_heroic = {
						order = 205,						
						type = "execute", 
						name = addon:GetDifficultyPrefix(15,"raid")..addon:HexColor(addon.db.profile.DropdownTextColorOptions.raidDifficultyHeroicColor, L.RaidDifficultyHeroicLabel)..addon:GetDifficultyPostfix(15,"raid"),						
						desc = L.RaidDifficultyHeroicDesc, 
						func = function() 
								SetRaidDifficultyID(15)
						       end,						
					},
					raid_difficulty_10_playerheroic = {
						order = 206,						
						type = "execute", 
						name = addon:GetDifficultyPrefix(5,"raid")..addon:HexColor(addon.db.profile.DropdownTextColorOptions.raidDifficulty10PlayerHeroicColor, L.RaidDifficulty10PlayerHeroicLabel)..addon:GetDifficultyPostfix(5,"raid"),						
						desc = L.RaidDifficulty10PlayerHeroicDesc, 
						func = function() 
								SetRaidDifficultyID(5)
						   	   end,						
					},
					raid_difficulty_25_player_heroic = {
						order = 207,						
						type = "execute", 
						name = addon:GetDifficultyPrefix(6,"raid")..addon:HexColor(addon.db.profile.DropdownTextColorOptions.raidDifficulty25PlayerHeroicColor, L.RaidDifficulty25PlayerHeroicLabel)..addon:GetDifficultyPostfix(6,"raid"),						
						desc = L.RaidDifficulty25PlayerHeroicDesc, 
						func = function() 
								SetRaidDifficultyID(6)
						   	   end,						
					},					
					raid_difficulty_mythic = {
						order = 208,						
						type = "execute", 
						name = addon:GetDifficultyPrefix(16,"raid")..addon:HexColor(addon.db.profile.DropdownTextColorOptions.raidDifficultyMythicColor, L.RaidDifficultyMythicLabel)..addon:GetDifficultyPostfix(16,"raid"),						
						desc = L.RaidDifficultyMythicDesc, 
						func = function() 
								SetRaidDifficultyID(16)
						       end,						
					},				    								
				},
			},
			legacy_raid_size_group_separator_header = { 
				order = 210,   
				type = 'header',
				name = L.EmptyString,
			},			
			legacy_raid_size_group_header = { 
				order = 220,   
				type = 'header',
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.legacyRaidDifficultyHeaderColor, L.LegacyRaidDifficultyHeaderLabel),				
			},
			legacy_raid_size_group_options = { 
				order = 230,
				type = 'group',
				name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.legacyRaidDifficultyOptionsColor, L.LegacyRaidDifficultyGroupOptionsLabel),				
				desc = L.LegacyRaidDifficultyGroupOptionsDesc,
				args = {					
					legacy_raid_size_header = { 
						order = 231,   
						type = 'header',
						name = addon:HexColor(addon.db.profile.DropdownTextColorOptions.selectALegacyRaidDifficultyHeaderColor, L.LegacyRaidDifficultySelectHeader),						
					},						
					legacy_raid_size_10_player = {
						order = 232,
						type = "execute", 
						name = addon:GetDifficultyPrefix(3,"legacy")..addon:HexColor(addon.db.profile.DropdownTextColorOptions.legacyRaidDifficulty10PlayerColor, L.LegacyRaidDifficulty10PlayerLabel)..addon:GetDifficultyPostfix(3,"legacy"),						
						desc = L.LegacyRaidDifficulty10PlayerDesc, 
						func = function() 
								SetLegacyRaidDifficultyID(3)
							   end,						
					},				    
					legacy_raid_size_25_player = {
						order = 233,
						type = "execute", 
						name = addon:GetDifficultyPrefix(4,"legacy")..addon:HexColor(addon.db.profile.DropdownTextColorOptions.legacyRaidDifficulty25PlayerColor, L.LegacyRaidDifficulty25PlayerLabel)..addon:GetDifficultyPostfix(4,"legacy"),						
						desc = L.LegacyRaidDifficulty25PlayerDesc, 
						func = function() 
								SetLegacyRaidDifficultyID(4)
							   end,						
					},	
					legacy_raid_size_10_playerheroic = {
						order = 234,						
						type = "execute", 
						name = addon:GetDifficultyPrefix(5,"legacy")..addon:HexColor(addon.db.profile.DropdownTextColorOptions.legacyRaidDifficulty10PlayerHeroicColor, L.LegacyRaidDifficulty10PlayerHeroicLabel)..addon:GetDifficultyPostfix(5,"legacy"),						
						desc = L.LegacyRaidDifficulty10PlayerHeroicDesc, 
						func = function() 
								SetLegacyRaidDifficultyID(5)
							   end,						
					},
					legacy_raid_size_25_player_heroic = {
						order = 235,						
						type = "execute", 
						name = addon:GetDifficultyPrefix(6,"legacy")..addon:HexColor(addon.db.profile.DropdownTextColorOptions.legacyRaidDifficulty25PlayerHeroicColor, L.LegacyRaidDifficulty25PlayerHeroicLabel)..addon:GetDifficultyPostfix(6,"legacy"),						
						desc = L.LegacyRaidDifficulty25PlayerHeroicDesc, 
						func = function() 
								SetLegacyRaidDifficultyID(6)
							   end,						
					},
				},				
			},
		}
	}
	
	barmenuframe = barmenuframe or LibDropdown:OpenAce3Menu(baropts)
	barmenuframe:SetClampedToScreen(true)
	barmenuframe:SetAlpha(1.0)
	barmenuframe:Show()

	local leftPos = myframe:GetLeft()
	local rightPos = myframe:GetRight()
	local side
	local oside
	if not rightPos then
		rightPos = 0
	end
	if not leftPos then
		leftPos = 0
	end

	local rightDist = GetScreenWidth() - rightPos

	if leftPos and rightDist < leftPos then
		side = "TOPLEFT"
		oside = "TOPRIGHT"
	else
		side = "TOPRIGHT"
		oside = "TOPLEFT"
	end

	barmenuframe:ClearAllPoints()
	barmenuframe:SetPoint(oside, myframe, side, 0, 0)
end

function addon:DisbandRaid()    
	local pName = UnitName("player") 
	local numGroupMembers = GetNumGroupMembers()

	if numGroupMembers > 0 then  
		for i = 1, numGroupMembers do
			local name = GetRaidRosterInfo(i) 
			if name ~= pName then       
				UninviteUnit(name) 
			end
		end 
		C_PartyInfo.LeaveParty()
	end
end

function addon:OpenLFRFrame()
	local avgItemLevel, avgItemLevelEquipped, avgItemLevelPvp = GetAverageItemLevel()
	
	--A player must be max level and have an average iLvl of 170, before they can open the Raid Finder window.
	if (UnitLevel("player")==GetMaxLevelForExpansionLevel(LE_EXPANSION_DRAGONFLIGHT)) and (avgItemLevel >= 170) and (avgItemLevelEquipped >= 170) then
		if not GroupFinderFrame:IsVisible() then
			PVEFrame_ShowFrame("GroupFinderFrame")
		end
		GroupFinderFrameGroupButton2:Click()
	else
		ToggleLFDParentFrame()
    end
end

function addon:OpenPremadeGroupsFrame()
	if not GroupFinderFrame:IsVisible() then
		PVEFrame_ShowFrame("GroupFinderFrame")
	end
	GroupFinderFrameGroupButton3:Click()
end

function addon:ToggleGreatVault()
	if UIParentLoadAddOn("Blizzard_WeeklyRewards") then
		if WeeklyRewardsFrame:IsShown() then
			WeeklyRewardsFrame:Hide()
		else
			WeeklyRewardsFrame:Show()
		end
	else 
		LoadAddOn("Blizzard_WeeklyRewards")
		WeeklyRewardsFrame:Show()
	end	
end

function addon:LeaveRaidFinderQueue()
	local mode, subMode = GetLFGMode(LE_LFG_CATEGORY_RF, RaidFinderQueueFrame.raid);
	if ( mode == "queued" or mode == "listed" or mode == "rolecheck" or mode == "suspended" ) then
		LeaveSingleLFG(LE_LFG_CATEGORY_RF, RaidFinderQueueFrame.raid);
	end
end

function addon:LeaveDungeonFinderQueue()
	local mode, subMode = GetLFGMode(LE_LFG_CATEGORY_LFD);
	if ( mode == "queued" or mode == "listed" or mode == "rolecheck" or mode == "suspended" ) then
		LeaveLFG(LE_LFG_CATEGORY_LFD);
	end
end

function addon:GetDifficultyPrefix(diff_id, diff_type)
	local prefix = L.EmptyString
	local dungeon_diff_id = GetDungeonDifficultyID()
	local raid_diff_id = GetRaidDifficultyID()
	local legacy_diff_id = GetLegacyRaidDifficultyID()

	if (((diff_type == "dungeon") and (diff_id == dungeon_diff_id)) or ((diff_type == "raid") and (diff_id == raid_diff_id)) or ((diff_type == "legacy") and (diff_id == legacy_diff_id))) then
		prefix = L.SelectedDifficultyPrefix
	end

	return prefix
end

function addon:GetDifficultyPostfix(diff_id, diff_type)
	local postfix = L.EmptyString
	local dungeon_diff_id = GetDungeonDifficultyID()
	local raid_diff_id = GetRaidDifficultyID()
	local legacy_diff_id = GetLegacyRaidDifficultyID()

	if (((diff_type == "dungeon") and (diff_id == dungeon_diff_id)) or ((diff_type == "raid") and (diff_id == raid_diff_id)) or ((diff_type == "legacy") and (diff_id == legacy_diff_id))) then
		postfix = L.SelectedDifficultyPostfix
	end

	return postfix
end

StaticPopupDialogs["CONFIRM_DISBAND_RAID"] = {
	text = L.CONFIRM_DISBAND_RAID,
	button1 = L.Yes,
	button2 = L.No,
	enterClicksFirstButton = 0, -- YES on enter
	hideOnEscape = 0, -- NO on escape
	timeout = 0,
	OnAccept = function() addon.DisbandRaid() end,
}

StaticPopupDialogs["CONFIRM_INSTANCE_RESET"] = {
	text = L.CONFIRM_INSTANCE_RESET,
	button1 = L.Yes,
	button2 = L.No,
	enterClicksFirstButton = 0, -- YES on enter
	hideOnEscape = 0, -- NO on escape
	timeout = 0,
	OnAccept = function() ResetInstances() end,
}

StaticPopupDialogs["CONFIRM_LEAVE_GROUP"] = {
	text = L.CONFIRM_LEAVE_GROUP,
	button1 = L.Yes,
	button2 = L.No,
	enterClicksFirstButton = 0, -- YES on enter
	hideOnEscape = 0, -- NO on escape
	timeout = 0,
	OnAccept = function() C_PartyInfo.LeaveParty() end,
}

StaticPopupDialogs["CONFIRM_LEAVE_RAID_FINDER_QUEUE"] = {
	text = L.CONFIRM_LEAVE_RAID_FINDER_QUEUE,
	button1 = L.Yes,
	button2 = L.No,
	enterClicksFirstButton = 0, -- YES on enter
	hideOnEscape = 0, -- NO on escape
	timeout = 0,
	OnAccept = function() addon.LeaveRaidFinderQueue() end,
}

StaticPopupDialogs["CONFIRM_LEAVE_DUNGEON_FINDER_QUEUE"] = {
	text = L.CONFIRM_LEAVE_DUNGEON_FINDER_QUEUE,
	button1 = L.Yes,
	button2 = L.No,
	enterClicksFirstButton = 0, -- YES on enter
	hideOnEscape = 0, -- NO on escape
	timeout = 0,
	OnAccept = function() addon.LeaveDungeonFinderQueue() end,
}
