--[[
Created: 2020-12-20
Updated: 2022-11-28
Author: Skadi of Dawnbringer-US
AddOn: Broker_GroupHelperRedux
Module: Click
Version: 10.0.2_R18
Description: Broker_GroupHelperRedux is an AddOn that allows you to conveniently access 
             many of the group and raid functions that exist in the game.
--]]

local name, addon = ...
local click = addon:NewModule('Click')

-- Localise global variables
local _G = _G
local LoadAddOn, ShowUIPanel, HideUIPanel = _G.LoadAddOn, _G.ShowUIPanel, _G.HideUIPanel
local EJ_GetInstanceForMap, EJ_GetDifficulty = _G.EJ_GetInstanceForMap, _G.EJ_GetDifficulty
local UnitClass, GetInstanceInfo = _G.UnitClass, _G.GetInstanceInfo
local GetBestMapForUnit = _G.C_Map.GetBestMapForUnit

local EncounterJournal, EncounterJournal_SetClassAndSpecFilter
local EncounterJournal_ListInstances, EncounterJournal_DisplayInstance, EncounterJournal_SelectDifficulty, EJSuggestFrame_OpenFrame

local function LoadEncounterJournal()
	if not _G.EncounterJournal then
		LoadAddOn('Blizzard_EncounterJournal')
	end

	EncounterJournal = _G.EncounterJournal
	EncounterJournal_SetClassAndSpecFilter = _G.EncounterJournal_SetClassAndSpecFilter
	EncounterJournal_ListInstances = _G.EncounterJournal_ListInstances
	EncounterJournal_DisplayInstance = _G.EncounterJournal_DisplayInstance
	EncounterJournal_SelectDifficulty = _G.EncounterJournal_SelectDifficulty
	EJSuggestFrame_OpenFrame = _G.EJSuggestFrame_OpenFrame	
end

function click:OnEnable()
	addon:Subscribe('MOUSE_CLICK', self, 'OnClick')
	addon:Subscribe('LOOT_SPEC_UPDATED', self, 'OnLootSpecUpdated')
end

function click:OnDisable()
	addon:Unsubscribe('MOUSE_CLICK', self, 'OnClick')
	addon:Unsubscribe('LOOT_SPEC_UPDATED', self, 'OnLootSpecUpdated')
end

function click:OnClick(frame, button)
	if button == 'LeftButton' then
		if not EncounterJournal then
			LoadEncounterJournal()
		end

		if EncounterJournal:IsShown() then
			HideUIPanel(EncounterJournal)
		else
			self.PrepareEncounterJournal()
			ShowUIPanel(EncounterJournal)
		end
	elseif button == "RightButton" then
		addon:GetModule("Dropdown"):PopulateDropdown(frame)
	end
end

function click:OnAdventureGuideClick()
	if not EncounterJournal then
		LoadEncounterJournal()
	end

	HideUIPanel(EncounterJournal)
	EJSuggestFrame_OpenFrame()
	ShowUIPanel(EncounterJournal)
end

function click:OnLootSpecUpdated()
	if EncounterJournal and EncounterJournal:IsShown() then
		self.PrepareEncounterJournal()
	end
end

function click.PrepareEncounterJournal()
	local _, _, class = UnitClass('player')
	local _, spec = addon.GetLootSpecialization()
	local instance = EJ_GetInstanceForMap(GetBestMapForUnit('player'))

	if instance > 0 then
		local _, _, difficulty = GetInstanceInfo()

		if instance ~= EncounterJournal.instanceID then
			EncounterJournal_ListInstances()
			EncounterJournal_DisplayInstance(instance)
		end

		if difficulty and difficulty ~= EJ_GetDifficulty() then
			EncounterJournal_SelectDifficulty(nil, difficulty)
		end
	end

	if spec then
		EncounterJournal_SetClassAndSpecFilter(nil, class, spec)
	else
		EncounterJournal_SetClassAndSpecFilter(nil, class, 0)
	end

	EncounterJournal.encounter.info.lootTab:Click()
end
