--[[
Created: 2020-12-20
Updated: 2022-11-28
Author: Skadi of Dawnbringer-US
AddOn: Broker_GroupHelperRedux
Module: Database-Defaults
Version: 10.0.2_R18
Description: Broker_GroupHelperRedux is an AddOn that allows you to conveniently access 
             many of the group and raid functions that exist in the game.
--]]

local name, addon = ...
local databaseDefaults = addon:NewModule('Database-Defaults')

-- Initialize default db values
local defaults = {
	profile = {
		TooltipOptions = {
			showLootSpecInfo = true,
			showInstanceInfo = true,
			showInstanceQueuesInfo = true
		},
		TooltipTextColorOptions = {			
			tooltipTitleHeaderColor = { r = 0, g = 1, b = 127/255 }, --Spring Green
			configurationOptionsColor = { r = 1, g = 1, b = 1 }, --White
			lootInfoHeaderColor = { r = 0, g = 1, b = 127/255 }, --Spring Green
			lootSpecLabelColor = { r = 1, g = 204/255, b = 0 }, --Tangerine Yellow
			lootSpecValueColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			lootSpecSelectionHeaderColor = { r = 1, g = 204/255, b = 0 }, --Tangerine Yellow
			lootSpecPrimaryValueColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			lootSpecSecondaryValueColor = { r = 1, g = 1, b = 1 }, --White
			instanceInfoHeaderColor = { r = 0, g = 1, b = 127/255 }, --Spring Green
			instanceInfoNameLabelColor = { r = 1, g = 204/255, b = 0 }, --Tangerine Yellow
			instanceInfoNameValueColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			instanceSubzoneLabelColor = { r = 1, g = 204/255, b = 0 }, --Tangerine Yellow
			instanceSubzoneValueColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			instanceInfoDungeonDiffLabelColor = { r = 1, g = 204/255, b = 0 }, --Tangerine Yellow
			instanceInfoDungeonDiffValueColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			instanceInfoRaidDiffLabelColor = { r = 1, g = 204/255, b = 0 }, --Tangerine Yellow
			instanceInfoRaidDiffValueColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			instanceInfoLegacyRaidDifficultyLabelColor = { r = 1, g = 204/255, b = 0 }, --Tangerine Yellow
			instanceInfoLegacyRaidDifficultyValueColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			instanceQueuesHeaderColor = { r = 0, g = 1, b = 127/255 }, --Spring Green
		},
		DropdownTextColorOptions = {
			dropdownTitleHeaderColor = { r = 0, g = 1, b = 127/255 }, --Spring Green
			readyCheckColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			dungeonsAndRaidsHeaderColor = { r = 0, g = 1, b = 127/255 }, --Spring Green
			legendaryPowersColor = { r = 1, g = 128/255, b = 0 }, --Dark Saturated Orange
			mythicKeystonesColor = { r = 1, g = 128/255, b = 0 }, --Dark Saturated Orange
			calendarColor = { r = 163/255, g = 53/255, b = 238/255 }, --Light Washed Purple
			adventureGuideColor = { r = 163/255, g = 53/255, b = 238/255 }, --Light Washed Purple
			greatVaultColor = { r = 163/255, g = 53/255, b = 238/255 }, --Light Washed Purple
			dungeonFinderColor = { r = 163/255, g = 53/255, b = 238/255 }, --Light Washed Purple
			raidFinderColor = { r = 163/255, g = 53/255, b = 238/255 }, --Light Washed Purple
			premadeGroupsColor = { r = 163/255, g = 53/255, b = 238/255 }, --Light Washed Purple
			groupUtilityOptionsHeaderColor = { r = 0, g = 1, b = 127/255 }, --Spring Green
			teleportInOutOfLFGInstanceColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			raidColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			raidInfoColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			convertToRaidColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			disbandRaidColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			resetAllInstancesColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			leaveGroupQueueOptionsHeaderColor = { r = 0, g = 1, b = 127/255 }, --Spring Green
			leaveGroupColor = { r = 1, g = 128/255, b = 0 }, --Dark Saturated Orange
			leaveTheDungeonFinderQueueColor = { r = 1, g = 128/255, b = 0 }, --Dark Saturated Orange
			leaveTheRaidFinderQueueColor = { r = 1, g = 128/255, b = 0 }, --Dark Saturated Orange
			dungeonDifficultyHeaderColor = { r = 0, g = 1, b = 127/255 }, --Spring Green
			dungeonDifficultyOptionsColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			selectADungeonDifficultyHeaderColor = { r = 0, g = 1, b = 127/255 }, --Spring Green
			dungeonDifficultyNormalColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			dungeonDifficultyHeroicColor = { r = 163/255, g = 53/255, b = 238/255 }, --Light Washed Purple
			dungeonDifficultyMythicColor = { r = 1, g = 128/255, b = 0 }, --Dark Saturated Orange
			raidDifficultyHeaderColor = { r = 0, g = 1, b = 127/255 }, --Spring Green
			raidDifficultyOptionsColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			selectARaidDifficultyHeaderColor = { r = 0, g = 1, b = 127/255 }, --Spring Green
			raidDifficultyNormalColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			raidDifficulty10PlayerColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			raidDifficulty25PlayerColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			raidDifficultyHeroicColor = { r = 163/255, g = 53/255, b = 238/255 }, --Light Washed Purple
			raidDifficulty10PlayerHeroicColor = { r = 163/255, g = 53/255, b = 238/255 }, --Light Washed Purple
			raidDifficulty25PlayerHeroicColor = { r = 163/255, g = 53/255, b = 238/255 }, --Light Washed Purple
			raidDifficultyMythicColor = { r = 1, g = 128/255, b = 0 }, --Dark Saturated Orange
			legacyRaidDifficultyHeaderColor = { r = 0, g = 1, b = 127/255 }, --Spring Green
			legacyRaidDifficultyOptionsColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue			
			selectALegacyRaidDifficultyHeaderColor = { r = 0, g = 1, b = 127/255 }, --Spring Green
			legacyRaidDifficulty10PlayerColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			legacyRaidDifficulty25PlayerColor = { r = 30/255, g = 144/255, b = 1 }, --Dodger Blue
			legacyRaidDifficulty10PlayerHeroicColor = { r = 163/255, g = 53/255, b = 238/255 }, --Light Washed Purple
			legacyRaidDifficulty25PlayerHeroicColor = { r = 163/255, g = 53/255, b = 238/255 }, --Light Washed Purple
		}					
	}
}

function databaseDefaults:GetDatabaseDefaults()	
	return defaults
end
