--[[
Created: 2020-12-20
Updated: 2022-11-28
Author: Skadi of Dawnbringer-US
AddOn: Broker_GroupHelperRedux
Module: Databroker
Version: 10.0.2_R18
Description: Broker_GroupHelperRedux is an AddOn that allows you to conveniently access 
             many of the group and raid functions that exist in the game.
--]]

local name, addon = ...
local broker = addon:NewModule('DataBroker')
local L = LibStub("AceLocale-3.0"):GetLocale(name)

function broker:OnInitialize()
	self.type = 'data source'
	self:SetValue('Unknown', 'Interface\\AddOns\\Broker_GroupHelperRedux\\media\\icon')

	LibStub('LibDataBroker-1.1'):NewDataObject(name, self)
end

function broker:OnEnable()
	addon:Subscribe('LOOT_SPEC_UPDATED', self, 'OnLootSpecUpdated')
	addon:TriggerLootSpecUpdated()
end

function broker:OnDisable()
	addon:Unsubscribe('LOOT_SPEC_UPDATED', self, 'OnLootSpecUpdated')
end

function broker:OnLootSpecUpdated()
	local lootspec, id, lootspecname, description, icon = addon.GetLootSpecialization()

	if not name then
		lootspecname = 'None'
	end

	if not icon then
		lootspecname = 'Interface\\Icons\\INV_Misc_QuestionMark'
	end

	if lootspec == 0 then
		lootspecname = lootspecname
	end

	if lootspecname:len() == 0 then
		lootspecname = L.LootSpecNotSelected
	end

	self:SetValue(lootspecname, icon)
end

function broker:SetValue(value, icon)
	self.text = value
	self.value = value
	self.icon = 'Interface\\AddOns\\Broker_GroupHelperRedux\\media\\icon'
end

function broker.OnEnter(frame)
	if broker.enabledState then
		addon:Publish('MOUSE_ENTER', frame)
	end
end

function broker.OnLeave(frame)
	if broker.enabledState then
		addon:Publish('MOUSE_LEAVE', frame)
	end
end

function broker.OnClick(frame, ...)
	if broker.enabledState then
		addon:Publish('MOUSE_CLICK', frame, ...)
	end
end
