--[[
Created: 2020-12-20
Updated: 2022-11-28
Author: Skadi of Dawnbringer-US
AddOn: Broker_GroupHelperRedux
Module: Tooltip-Instance Info
Version: 10.0.2_R18
Description: Broker_GroupHelperRedux is an AddOn that allows you to conveniently access 
             many of the group and raid functions that exist in the game.
--]]

local name, addon = ...
local tooltipInstanceInfo = addon:NewModule('Tooltip-InstanceInfo')
local L = LibStub("AceLocale-3.0"):GetLocale(name)

function tooltipInstanceInfo:PopulateInstanceInfo(tooltip)
	local instanceName, _, _, difficultyName, _, _, _, _, _ = GetInstanceInfo()
	local inInstance, instanceType = IsInInstance()
	local instanceSubZone = GetSubZoneText() or ""

	--(id, icon, name, active, texttype, cell2text)
	tooltip:AddLine(0, L.EmptyString, addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoHeaderColor, L.InstanceInfoHeader), false, 'headertext', L.EmptyString)
	tooltip.tip:AddLine(L.EmptyString)
	tooltip.tip:AddSeparator(2,0,1,1)
	tooltip.tip:AddLine(L.EmptyString)

	if inInstance then		
		if instanceType=='party' then
		   --(id, icon, name, active, texttype, cell2text)
		   tooltip:AddLine(0, L.EmptyString, addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoNameLabelColor, L.InstanceName), false, 'normaltext', addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoNameValueColor, instanceName))

		   --(id, icon, name, active, texttype, cell2text)
		   tooltip:AddLine(0, L.EmptyString, addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceSubzoneLabelColor, L.InstanceSubzone), false, 'normaltext', addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceSubzoneValueColor, instanceSubZone))

		   --(id, icon, name, active, texttype, cell2text)
		   tooltip:AddLine(0, L.EmptyString, addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoDungeonDiffLabelColor, L.DungeonDifficulty), false, 'normaltext', addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoDungeonDiffValueColor, difficultyName))
		elseif instanceType=='raid' then		
		   local legacyRaidDifficultyID = GetLegacyRaidDifficultyID()
		   local legacyRaidDifficultyName, legacyRaidGroupType, legacyRaidIsHeroic, legacyRaidIsChallengeMode, legacyRaidDisplayHeroic, legacyRaidDisplayMythic, legacyRaidToggleDifficultyID = GetDifficultyInfo(legacyRaidDifficultyID)			   
		   
		   --(id, icon, name, active, texttype, cell2text)
		   tooltip:AddLine(0, L.EmptyString, addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoNameLabelColor, L.InstanceName), false, 'normaltext', addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoNameValueColor, instanceName))

		   --(id, icon, name, active, texttype, cell2text)
		   tooltip:AddLine(0, L.EmptyString, addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceSubzoneLabelColor, L.InstanceSubzone), false, 'normaltext', addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceSubzoneValueColor, instanceSubZone))		   

		   --(id, icon, name, active, texttype, cell2text)
		   tooltip:AddLine(0, L.EmptyString, addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoRaidDiffLabelColor, L.RaidDifficulty), false, 'normaltext', addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoRaidDiffValueColor, difficultyName))

		   if legacyRaidDifficultyName ~= nil then
              --(id, icon, name, active, texttype, cell2text)
              tooltip:AddLine(0, L.EmptyString, addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoLegacyRaidDifficultyLabelColor, L.LegacyRaidDifficulty), false, 'normaltext', addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoLegacyRaidDifficultyValueColor, legacyRaidDifficultyName))
		   end
		elseif instanceType=='scenario' then
		   --(id, icon, name, active, texttype, cell2text)
		   tooltip:AddLine(0, L.EmptyString, addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoNameLabelColor, L.InstanceName), false, 'normaltext', addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoNameValueColor, instanceName))

		   --(id, icon, name, active, texttype, cell2text)
		   tooltip:AddLine(0, L.EmptyString, addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceSubzoneLabelColor, L.InstanceSubzone), false, 'normaltext', addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceSubzoneValueColor, instanceSubZone))
		end
	else
		local dungeonDifficultyId = GetDungeonDifficultyID()		
		local dungeonDifficultyName, dungeonGroupType, dungeonIsHeroic, dungeonIsChallengeMode, dungeonDisplayHeroic, dungeonDisplayMythic, dungeonToggleDifficultyID = GetDifficultyInfo(dungeonDifficultyId)		
	
		local raidDifficultyID = GetRaidDifficultyID()
		local raidDifficultyName, raidGroupType, raidIsHeroic, raidIsChallengeMode, raidDisplayHeroic, raidDisplayMythic, raidToggleDifficultyID = GetDifficultyInfo(raidDifficultyID)
		
		local legacyRaidDifficultyID = GetLegacyRaidDifficultyID()		
		local legacyRaidDifficultyName, legacyRaidGroupType, legacyRaidIsHeroic, legacyRaidIsChallengeMode, legacyRaidDisplayHeroic, legacyRaidDisplayMythic, legacyRaidToggleDifficultyID = GetDifficultyInfo(legacyRaidDifficultyID)		
		
		--(id, icon, name, active, texttype, cell2text)
		tooltip:AddLine(0, L.EmptyString, addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoDungeonDiffLabelColor, L.DungeonDifficulty), false, 'normaltext', addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoDungeonDiffValueColor, dungeonDifficultyName))

		--(id, icon, name, active, texttype, cell2text)
		tooltip:AddLine(0, L.EmptyString, addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoRaidDiffLabelColor, L.RaidDifficulty), false, 'normaltext', addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoRaidDiffValueColor, raidDifficultyName))

		--(id, icon, name, active, texttype, cell2text)
		tooltip:AddLine(0, L.EmptyString, addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoLegacyRaidDifficultyLabelColor, L.LegacyRaidDifficulty), false, 'normaltext', addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceInfoLegacyRaidDifficultyValueColor, legacyRaidDifficultyName))
	end
end 
