--[[
Created: 2020-12-20
Updated: 2022-11-28
Author: Skadi of Dawnbringer-US
AddOn: Broker_GroupHelperRedux
Module: Tooltip-LFG Queue Status
Version: 10.0.2_R18
Description: Broker_GroupHelperRedux is an AddOn that allows you to conveniently access 
             many of the group and raid functions that exist in the game.
--]]

local name, addon = ...
local tooltipLFG = addon:NewModule('Tooltip-LFG')
local L = LibStub("AceLocale-3.0"):GetLocale(name)

local menuIcon={}
local menuRow1={}
local menuRow2={}
local menuColor={}
local qcnt=0

local vars={}
local icons={}

vars.tankWait=0;
vars.healWait=0;
vars.dpsWait=0;
vars.avgWait=0;
vars.myWait=0;

vars.updatetime=2; --- Update Every x aseconds.
vars.starttime={}

vars.starttime[LE_LFG_CATEGORY_LFD]=0
vars.starttime[LE_LFG_CATEGORY_LFR]=0
vars.starttime[LE_LFG_CATEGORY_RF]=0
vars.starttime[LE_LFG_CATEGORY_SCENARIO]=0
vars.starttime[LE_LFG_CATEGORY_FLEXRAID]=0 

icons.tank = "Interface\\Icons\\Spell_Holy_AvengersShield"
icons.dps = "Interface\\Icons\\Spell_Holy_BlessingOfStrength"
icons.heals = "Interface\\Icons\\Spell_Holy_HolyGuidance"

C_Timer.After(2, function ()  tooltipLFG:update() end)

function tooltipLFG:PopulateLFGQueueStatus(tooltip)	
	--(id, icon, name, active, texttype, cell2text)
	tooltip:AddLine(0, L.EmptyString, addon:HexColor(addon.db.profile.TooltipTextColorOptions.instanceQueuesHeaderColor, L.InstanceQueuesHeader), false, 'headertext', L.EmptyString)
	tooltip.tip:AddLine(L.EmptyString)
	tooltip.tip:AddSeparator(2,0,1,1)
	tooltip.tip:AddLine(L.EmptyString)	

	maxr=#menuRow1;
	
	local row =0
	local col =0
	
	for n = 1,maxr do 
		if menuRow1[n]=="<br/>" then --- line/section break
			tooltip.tip:AddSeparator(1, .5, .5, .5, 1)
		elseif menuIcon[n]=="header" then
			row, col= tooltip.tip:AddHeader(menuRow1[n], menuRow2[n]);
		elseif menuIcon[n]=="" then
			row, col= tooltip.tip:AddLine(menuRow1[n], menuRow2[n]);
		else
			row, col= tooltip.tip:AddLine("|TInterface\\Icons\\"..menuIcon[n]..".blp:16|t "..menuRow1[n], menuRow2[n]);
		end
		
		if menuRow1[n]~="<br/>" then 
		    local r,g,b=self:GetBackCol(menuColor[n]);
			tooltip.tip:SetLineColor(row,r,g,b,1)
		end
	end
end

function tooltipLFG:GetBackCol(colorName)
	--- misc menu items
	if colorName=="miscTitle" then
		return 32/255,128/255,208/255
	elseif colorName=="misc" then
		return 192/255,224/255,255/255	
	--- Raid menu items
	elseif colorName=="raidTitle" then
		return 255/255,128/255,0
	elseif colorName=="raid" then
		return 255/255,192/255,128/255	
	--- Dungeon menu items
	elseif colorName=="dungeonTitle" then
			return 64/255,160/255,64/255
	elseif colorName=="dungeon" then
		return 128/255,176/255,128/255	
	-- Others
	elseif colorName=="odd" then
		return 0.047,0.188,.266
	elseif colorName=="time" then
		return 112/266,96/266,112/255	
	end
	
	return 0,0,0
end

function tooltipLFG:Clear()
	menuIcon={}
	menuRow1={}
	menuRow2={}
	menuColor={}
	qcnt=0
end

function tooltipLFG:Reset()
	menuIcon={"","INV_Misc_ClothScrap_02"}
	menuRow1={"<br/>","|cff606060"..L.NotInQueue}
	menuRow2={"",""}
	menuColor={"CF4040","CF4040"}
	qcnt=0
end

function tooltipLFG:Add(tankNeeds, healerNeeds, dpsNeeds, tankTotal, healerTotal, dpsTotal, iType, instanceName,leaderNeeds, timestring)
	if (iType==0) then -- None
		self:Reset();	
	elseif (iType==LE_LFG_CATEGORY_LFD) then -- Instance
		self:AddRow("","<br/>","","")
		self:AddRow("header","|cffffffff"..instanceName.."|r(LFD)","","dungeonTitle")
		self:AddRow("Spell_Holy_AvengersShield",L.Tanks,self:GetQueueStateText(tankTotal,tankNeeds),"")
		self:AddRow("Spell_Holy_BlessingOfStrength",L.DPS,self:GetQueueStateText(dpsTotal,dpsNeeds),"odd")
		self:AddRow("Spell_Holy_HolyGuidance",L.Heals,self:GetQueueStateText(healerTotal,healerNeeds),"")
		self:AddRow("INV_Misc_PocketWatch_02",L.Waiting,"|cff00FFFF"..timestring,"odd")
	elseif (iType==LE_LFG_CATEGORY_LFR) then -- 
		self:AddRow("","<br/>","","")
		self:AddRow("header","|cffffffff"..instanceName.."|r(LFR)","","raidTitle")
		self:AddRow("Spell_Holy_AvengersShield",L.Tanks,self:GetQueueStateText(tankTotal,tankNeeds),"")
		self:AddRow("Spell_Holy_BlessingOfStrength",L.DPS,self:GetQueueStateText(dpsTotal,dpsNeeds),"odd")
		self:AddRow("Spell_Holy_HolyGuidance",L.Heals,self:GetQueueStateText(healerTotal,healerNeeds),"")
		self:AddRow("INV_Misc_PocketWatch_02",L.Waiting,"|cff00FFFF"..timestring,"odd")	
	elseif (iType==LE_LFG_CATEGORY_RF) then -- 	
		self:AddRow("","<br/>","","")
		self:AddRow("header","|cffffffff"..instanceName.."|r(RF)","","raidTitle")
		self:AddRow("Spell_Holy_AvengersShield",L.Tanks,self:GetQueueStateText(tankTotal,tankNeeds),"")
		self:AddRow("Spell_Holy_BlessingOfStrength",L.DPS,self:GetQueueStateText(dpsTotal,dpsNeeds),"odd")
		self:AddRow("Spell_Holy_HolyGuidance",L.Heals,self:GetQueueStateText(healerTotal,healerNeeds),"")
		self:AddRow("INV_Misc_PocketWatch_02",L.Waiting,"|cff00FFFF"..timestring,"odd")	
	elseif (iType==LE_LFG_CATEGORY_SCENARIO) then -- 	
		self:AddRow("","<br/>","","")
		self:AddRow("header","|cffffffff"..instanceName.."|r(Scenario)","","miscTitle")
		self:AddRow("Spell_Holy_BlessingOfStrength",L.Players,self:GetQueueStateText(dpsTotal,dpsNeeds),"")
		self:AddRow("INV_Misc_PocketWatch_02",L.Waiting,"|cff00FFFF"..timestring,"odd")	
	elseif (iType==LE_LFG_CATEGORY_FLEXRAID) then -- 
		self:AddRow("","<br/>","","")
		self:AddRow("header","|cffffffff"..instanceName.."|r(RF)","","raidTitle")
		self:AddRow("Spell_Holy_AvengersShield",L.Tanks,self:GetQueueStateText(tankTotal,tankNeeds),"")
		self:AddRow("Spell_Holy_BlessingOfStrength",L.DPS,self:GetQueueStateText(dpsTotal,dpsNeeds),"odd")
		self:AddRow("Spell_Holy_HolyGuidance",L.Heals,self:GetQueueStateText(healerTotal,healerNeeds),"")
		self:AddRow("INV_Misc_PocketWatch_02",L.Waiting,"|cff00FFFF"..timestring,"odd")	
	end
	
	qcnt=qcnt+1
end

function tooltipLFG:GetQueueStateText(max,need)	
	if max==0 then return "|cff606060N/A" end	
	
	return self:GetQueueStateColor(max,need)..(max-need).."/"..max;
end

function tooltipLFG:GetQueueStateColor(max,need)
	col = "|cffff0000"
	
	if max==0 then 
		return col
	end
	
	if (need/max)<0.5 then
		col = "|cffFF8000"	
	elseif (need==0) then
		col = "|cff00ff00"
	end

	return col
end

function tooltipLFG:AddRow(Icon, LineText, LineCount,LineColor)
	 table.insert(menuIcon,""..Icon)
	 table.insert(menuRow1,""..LineText)
	 table.insert(menuRow2,""..LineCount)
	 table.insert(menuColor,""..LineColor)
end

function tooltipLFG:TimeString(secs)
	if (secs==nil) then
		return "-";
	end
	
	if (secs<60) then
		return "< 1m";
	end	
	
	local mins=math.floor(secs/60);
	local hours=0;
	local days=0;

	hours,mins=math.modf(mins/60);
	mins=math.floor(mins*60);

	days,hours=math.modf(hours/24);

	hours=math.floor(hours*24);

	sret=""
	if (days>0) then
		sret=days.."d ";
	end

	if (hours>0 or days>0) then
		sret=sret..hours.."h ";
	end

	sret=sret..mins.."m ";

	return sret;
end

function tooltipLFG:update()
	self:Clear();
	 
	local cnt=0
	
	cnt=cnt+self:updateQueue(LE_LFG_CATEGORY_LFD);
	cnt=cnt+self:updateQueue(LE_LFG_CATEGORY_LFR);
	cnt=cnt+self:updateQueue(LE_LFG_CATEGORY_RF);
	cnt=cnt+self:updateQueue(LE_LFG_CATEGORY_SCENARIO);
	cnt=cnt+self:updateQueue(LE_LFG_CATEGORY_FLEXRAID);

	if cnt==0 then			
		self:Reset()
	end	
	
	C_Timer.After(2, function () self:update() end)
end

function tooltipLFG:updateQueue(qID)
	local lfdmode, lfdsubmode=GetLFGMode(qID);

	if (lfdmode=="queued") then			
		if (vars.starttime[qID]==0) then 
			vars.starttime[qID]=time(); --- Start time
		end			

		local hasData, leaderNeeds, tankNeeds, healerNeeds, dpsNeeds, tankTotal, healerTotal, dpsTotal, instanceType, instanceSubType, instanceName, averageWait, tankWait, healerWait, damageWait, myWait = GetLFGQueueStats(qID);
					
		if (not hasData) then
			return 0;
		end

		------ Store Times for Tooltip
		vars.tankWait=tankWait;
		vars.healWait=healerWait;
		vars.dpsWait=damageWait;
		vars.avgWait=averageWait;
		vars.myWait=myWait;			
		
		if (myWait<0) then
			------ Update Tooltip
			if (vars.starttime[qID]==0) then return end; --- LFG Not Active
			
			self:Add(tankNeeds, healerNeeds, dpsNeeds, tankTotal, healerTotal, dpsTotal ,qID, instanceName,leaderNeeds,self:TimeString(time()-vars.starttime[qID]))
		else
			------ Update Tooltip				
			self:Add(tankNeeds, healerNeeds, dpsNeeds, tankTotal, healerTotal, dpsTotal ,qID, instanceName,leaderNeeds,self:TimeString(time()-vars.starttime[qID]).." |cffFFFF00("..self:TimeString(myWait).." wait)")
		end

		return 1;
	else
		vars.starttime[qID]=0; -- Reset start Time
		return 0;		
	end	
end
