--[[
Created: 2020-12-20
Updated: 2022-11-28
Author: Skadi of Dawnbringer-US
AddOn: Broker_GroupHelperRedux
Module: Tooltip-Loot Spec Info
Version: 10.0.2_R18
Description: Broker_GroupHelperRedux is an AddOn that allows you to conveniently access 
             many of the group and raid functions that exist in the game.
--]]

local name, addon = ...
local tooltipLootSpec = addon:NewModule('Tooltip-LootSpec')
local L = LibStub("AceLocale-3.0"):GetLocale(name)

function tooltipLootSpec:PopulateLootSpecInfo(tooltip)
	local lootspec, _, lootspecname, _, _ = addon.GetLootSpecialization()
	local spec = GetSpecialization()
	local specname, icon = 'None', 'Interface\\Icons\\INV_Misc_QuestionMark'
	local id, _

	if lootspecname:len() == 0 then
		lootspecname = L.LootSpecNotSelected
	end
	
	--(id, icon, name, active, texttype, cell2text)
	tooltip:AddLine(0, L.EmptyString, addon:HexColor(addon.db.profile.TooltipTextColorOptions.lootInfoHeaderColor, L.LootInfoHeader), false, 'headertext', L.EmptyString)
	tooltip.tip:AddLine(L.EmptyString)
	tooltip.tip:AddSeparator(2,0,1,1)
	tooltip.tip:AddLine(L.EmptyString)

	--(id, icon, name, active, texttype, cell2text)
	tooltip:AddLine(0, L.EmptyString, addon:HexColor(addon.db.profile.TooltipTextColorOptions.lootSpecLabelColor, L.LootSpecialization), false, 'normaltext', addon:HexColor(addon.db.profile.TooltipTextColorOptions.lootSpecValueColor, lootspecname))
	tooltip.tip:AddLine(L.EmptyString)
	tooltip.tip:AddSeparator(2,0,1,1)
	tooltip.tip:AddLine(L.EmptyString)

	--(id, icon, name, active, texttype, cell2text)
	tooltip:AddLine(0, L.EmptyString, addon:HexColor(addon.db.profile.TooltipTextColorOptions.lootSpecSelectionHeaderColor, L.LootSpecSelect), false, 'normaltext', L.EmptyString)
	tooltip.tip:AddLine(L.EmptyString)
	tooltip.tip:AddSeparator(2,0,1,1)
	tooltip.tip:AddLine(L.EmptyString)		

	if spec then
		id, specname, _, icon = GetSpecializationInfo(spec)
	end

	if specname:len() == 0 then
		specname = L.LootSpecNotSelected
	end
	
	if lootspec == 0 then
		--(id, icon, specname, active, texttype, cell2text)
		tooltip:AddLine(0, icon, addon:HexColor(addon.db.profile.TooltipTextColorOptions.lootSpecPrimaryValueColor, format(LOOT_SPECIALIZATION_DEFAULT, specname)), lootspec == 0, L.EmptyString, L.EmptyString)
	else
		--(id, icon, specname, active, texttype, cell2text)
		tooltip:AddLine(0, icon, addon:HexColor(addon.db.profile.TooltipTextColorOptions.lootSpecSecondaryValueColor, format(LOOT_SPECIALIZATION_DEFAULT, specname)), lootspec == 0, L.EmptyString, L.EmptyString)
	end	

	for i = 1, GetNumSpecializations() do
		id, specname, _, icon = GetSpecializationInfo(i)		
		
		if lootspec == id then
			--(id, icon, specname, active, texttype, cell2text)
			tooltip:AddLine(id, icon, addon:HexColor(addon.db.profile.TooltipTextColorOptions.lootSpecPrimaryValueColor, specname), lootspec == id, L.EmptyString, L.EmptyString)			
		else
			--(id, icon, specname, active, texttype, cell2text)
			tooltip:AddLine(id, icon, addon:HexColor(addon.db.profile.TooltipTextColorOptions.lootSpecSecondaryValueColor, specname), lootspec == id, L.EmptyString, L.EmptyString)
		end		
	end
end 
