--[[
Created: 2020-12-20
Updated: 2022-11-28
Author: Skadi of Dawnbringer-US
AddOn: Broker_GroupHelperRedux
Module: Tooltip
Version: 10.0.2_R18
Description: Broker_GroupHelperRedux is an AddOn that allows you to conveniently access 
             many of the group and raid functions that exist in the game.
--]]

local name, addon = ...
local tooltip = addon:NewModule('Tooltip')
local L = LibStub("AceLocale-3.0"):GetLocale(name)

-- Localise global variables
local _G = _G
local GetSpecialization, GetSpecializationInfo = _G.GetSpecialization, _G.GetSpecializationInfo
local GetNumSpecializations, LOOT_SPECIALIZATION_DEFAULT = _G.GetNumSpecializations, _G.LOOT_SPECIALIZATION_DEFAULT
local format = _G.string.format

local LibQTip = LibStub('LibQTip-1.0')

function tooltip:OnEnable()
	addon:Subscribe('MOUSE_ENTER', self, 'Show')
	addon:Subscribe('MOUSE_CLICK', self, 'OnClick')
	addon:Subscribe('LOOT_SPEC_UPDATED', self, 'OnLootSpecUpdated')
end

function tooltip:OnDisable()
	self:Hide()
	addon:Unsubscribe('MOUSE_ENTER', self, 'Show')
	addon:Unsubscribe('MOUSE_CLICK', self, 'OnClick')
	addon:Unsubscribe('LOOT_SPEC_UPDATED', self, 'OnLootSpecUpdated')
end

function tooltip:OnClick(frame, button)
	if button == 'LeftButton' then
		self:Show(frame)
	end
end

function tooltip:OnLootSpecUpdated()
	self:Hide()
end

function tooltip:Show(anchor)
	self:Hide()

	if self.enabledState then
		self.tip = LibQTip:Acquire(name .. 'Tooltip', 2, 'LEFT', 'LEFT')
		self.tip:Clear()
		
		--(id, icon, name, active, texttype, cell2text)
		self:AddLine(0, L.EmptyString, addon:HexColor(addon.db.profile.TooltipTextColorOptions.tooltipTitleHeaderColor, L.Broker_GroupHelperReduxHeader .. ": " .. L.ReleaseVersion), false, 'headertext', L.EmptyString)
		self.tip:AddLine(L.EmptyString)
		self.tip:AddSeparator(2,0,1,1)
		self.tip:AddLine(L.EmptyString)

		--(id, icon, name, active, texttype, cell2text)
		self:AddLine(0, L.EmptyString, '|TInterface\\Icons\\INV_Misc_Wrench_02.blp:16|t ' .. addon:HexColor(addon.db.profile.TooltipTextColorOptions.configurationOptionsColor, L.ConfigOptionsLabel), false, 'configoptionstext', L.EmptyString)		
		self.tip:AddLine(L.EmptyString)
		self.tip:AddSeparator(2,0,1,1)
		self.tip:AddLine(L.EmptyString)

		self:PopulateTooltip()

		self.tip:AddLine(L.EmptyString)
		self.tip:AddSeparator(2,0,1,1)
		self.tip:AddLine(L.EmptyString)
	
		self.tip:AddLine('|cFFEDA55F'..L.LeftClick..'|r | '..'|cFF00FF7F'..L.AdventureGuideLeftClick..'|r')	
		self.tip:AddLine('|cFFEDA55F'..L.RightClick..'|r | '..'|cFF00FF7F'..L.InstanceOptionMenuRightClick..'|r')		

		self.tip.OnRelease = function() self.tip = nil end
		self.tip:SetAutoHideDelay(0.1, anchor)
		self.tip:SmartAnchorTo(anchor)
		self.tip:Show()
	end
end

function tooltip:Hide()
	if self.tip then
		LibQTip:Release(self.tip)
	end
end

function tooltip:PopulateTooltip()
	if (addon.db.profile.TooltipOptions.showLootSpecInfo) then
		addon:GetModule("Tooltip-LootSpec"):PopulateLootSpecInfo(self)
	end

	if (addon.db.profile.TooltipOptions.showInstanceInfo) then
		self.tip:AddLine(L.EmptyString)
		self.tip:AddSeparator(2,0,1,1)
		self.tip:AddLine(L.EmptyString)

		addon:GetModule("Tooltip-InstanceInfo"):PopulateInstanceInfo(self)
	end

	if (addon.db.profile.TooltipOptions.showInstanceQueuesInfo) then
		self.tip:AddLine(L.EmptyString)
		self.tip:AddSeparator(2,0,1,1)
		self.tip:AddLine(L.EmptyString)

		addon:GetModule("Tooltip-LFG"):PopulateLFGQueueStatus(self)
	end
end

function tooltip:AddLine(id, icon, name, active, texttype, cell2text)
	local line = self.tip:AddLine()
	local radio = '|T:0|t'		

	if active then
		radio = '|TInterface\\Buttons\\UI-RadioButton:8:8:0:0:64:16:19:28:3:12|t'
	end
	
	if texttype == 'headertext' then
		self.tip:SetCell(line, 1, (name or ""))
		self.tip:SetCell(line, 2, L.EmptyString)
	elseif texttype == 'normaltext' then
		self.tip:SetCell(line, 1, (name or ""))
		self.tip:SetCell(line, 2, (cell2text or ""))
	elseif texttype == 'configoptionstext' then
		self.tip:SetCell(line, 1, (name or ""))
		self.tip:SetCell(line, 2, L.EmptyString)
		self.tip:SetLineScript(line, 'OnMouseDown', self:GetConfigOptionsLineScript())
	else
		self.tip:SetCell(line, 1, radio .. L.SpaceString .. '|T' .. (icon or "") .. ':14|t' .. L.SpaceString .. (name or ""))
		self.tip:SetCell(line, 2, L.EmptyString)
		self.tip:SetLineScript(line, 'OnMouseUp', self:GetLineScript(id))
	end

	return line
end

function tooltip:GetLineScript(id)
	return function()
		addon.SetLootSpecialization(id)
		self:Hide()
	end
end

function tooltip:GetConfigOptionsLineScript()
	return function()
		addon:GetModule("Config-Main"):OpenOptions()
	end
end
